<?php
/**
 * Tests de fonctionnalités
 * 
 * @package tests
 */
class ControllerTest extends Zend_Test_PHPUnit_ControllerTestCase
{
    public $bootstrap = './Bootstrap.php';

    public function testRoutePerso()
    {
        $this->dispatch('/lister-les-reservations-page-1?format=xml');
        $this->assertHeaderContains('content-type', 'application/xml');
        $this->assertRoute('reservations');
    }

    public function testAccesPageRestreintRedirige()
    {
        $this->dispatch('/reservation/edit/');
        $this->assertRedirectRegex('#unauthorized#');
    }

    public function testLoginKo()
    {
         $this->request->setMethod('POST')
              ->setPost(array(
                  'login' => 'julien.pauli@anaska.com',
                  'password' => 'toto'
              ));
        $this->dispatch('/login/login/');        
        $this->assertResponseCode(303);
        $this->assertRedirect();
        $this->assertFalse(Zend_Auth::getInstance()->hasIdentity());
        $this->assertFalse(Zend_Session::namespaceIsset('Zend_Auth'));
    }

    public function testLoginOk()
    {
          $this->request->setMethod('POST')
              ->setPost(array(
                  'login' => 'julien.pauli@anaska.com',
                  'password' => 'julien'
              ));
          $this->dispatch('/login/login/');
          $this->assertResponseCode(302);
          $this->assertRedirect();
          $this->assertTrue(Zend_Auth::getInstance()->hasIdentity());
          $this->assertTrue(Zend_Session::namespaceIsset('Zend_Auth'));
    }

    public function testAccesRestreintQuandLoggueFonctionne()
    {
        $this->_logAdmin();
        $this->dispatch('/reservation/edit/');   
        $this->assertNotRedirect();
    }

    public function testEditionFaitApparaitreFormulaireDedition()
    {
        $this->_logAdmin();
        $this->dispatch('/reservation/edit/');
        $this->assertQuery("div#reservationform");
    }

    public function testLogout()
    {
        $this->dispatch('/login/logout/');
        $this->assertRedirect();
    }

    private function _logAdmin()
    {
        $admin = new stdClass();
        $admin->firstname = 'julien';
        Zend_Auth::getInstance()->getStorage()->write($admin);
        Zend_Registry::get('session')->acl->allow('user');
    }
}
